==> test-framework-202.7319.50-sources.jar: com/intellij/testFramework/EmptyFileBasedIndex.java <==
// Copyright 2000-2020 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.testFramework;

import com.intellij.openapi.progress.ProgressIndicator;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.roots.ContentIterator;
import com.intellij.openapi.util.Computable;
import com.intellij.openapi.util.Condition;
import com.intellij.openapi.util.ThrowableComputable;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.psi.search.GlobalSearchScope;
import com.intellij.util.Processor;
import com.intellij.util.indexing.*;
import com.intellij.util.indexing.impl.AbstractUpdateData;
import com.intellij.util.indexing.roots.IndexableFilesProvider;
import com.intellij.util.indexing.snapshot.SnapshotSingleValueIndexStorage;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.*;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReadWriteLock;
import java.util.concurrent.locks.ReentrantReadWriteLock;
import java.util.function.IntPredicate;

public class EmptyFileBasedIndex extends FileBasedIndexEx {
  private static final ThreadLocal<DumbModeAccessType> ourDumbModeAccessType = new ThreadLocal<>();

  @Override
  public void iterateIndexableFiles(@NotNull ContentIterator processor, @NotNull Project project, @Nullable ProgressIndicator indicator) {
  }

  @Override
  public @Nullable VirtualFile getFileBeingCurrentlyIndexed() {
    return null;
  }

  @Override
  public DumbModeAccessType getCurrentDumbModeAccessType() {
    return ourDumbModeAccessType.get();
  }

  @Override
  public void registerIndexableSet(@NotNull IndexableFileSet set, @Nullable Project project) {

  }

  @Override
  public void removeIndexableSet(@NotNull IndexableFileSet set) {

  }

  @Override
  public VirtualFile findFileById(Project project, int id) {
    return null;
  }

  @Override
  public void requestRebuild(@NotNull ID<?, ?> indexId) {
    super.requestRebuild(indexId);
  }

  @Override
  public @NotNull <K, V> List<V> getValues(@NotNull ID<K, V> indexId, @NotNull K dataKey, @NotNull GlobalSearchScope filter) {
    return Collections.emptyList();
  }

  @Override
  public @NotNull <K, V> Collection<VirtualFile> getContainingFiles(@NotNull ID<K, V> indexId,
                                                                    @NotNull K dataKey,
                                                                    @NotNull GlobalSearchScope filter) {
    return Collections.emptyList();
  }

  @Override
  public <K, V> boolean processValues(@NotNull ID<K, V> indexId,
                                      @NotNull K dataKey,
                                      @Nullable VirtualFile inFile,
                                      @NotNull ValueProcessor<? super V> processor,
                                      @NotNull GlobalSearchScope filter) {
    return true;
  }

  @Override
  public <K, V> boolean processValues(@NotNull ID<K, V> indexId,
                                      @NotNull K dataKey,
                                      @Nullable VirtualFile inFile,
                                      @NotNull ValueProcessor<? super V> processor,
                                      @NotNull GlobalSearchScope filter,
                                      @Nullable IdFilter idFilter) {
    return super.processValues(indexId, dataKey, inFile, processor, filter, idFilter);
  }

  @Override
  public <K, V> long getIndexModificationStamp(@NotNull ID<K, V> indexId, @NotNull Project project) {
    return 0;
  }

  @Override
  public <K, V> boolean processFilesContainingAllKeys(@NotNull ID<K, V> indexId,
                                                      @NotNull Collection<? extends K> dataKeys,
                                                      @NotNull GlobalSearchScope filter,
                                                      @Nullable Condition<? super V> valueChecker,
                                                      @NotNull Processor<? super VirtualFile> processor) {
    return true;
  }

  @Override
  public @NotNull <K> Collection<K> getAllKeys(@NotNull ID<K, ?> indexId, @NotNull Project project) {
    return Collections.emptyList();
  }

  @Override
  public <K> void ensureUpToDate(@NotNull ID<K, ?> indexId, @Nullable Project project, @Nullable GlobalSearchScope filter) {

  }

  @Override
  public void requestRebuild(@NotNull ID<?, ?> indexId, @NotNull Throwable throwable) {

  }

  @Override
  public <K> void scheduleRebuild(@NotNull ID<K, ?> indexId, @NotNull Throwable e) {

  }

  @Override
  public void requestReindex(@NotNull VirtualFile file) {

  }

  @Override
  public <K, V> boolean getFilesWithKey(@NotNull ID<K, V> indexId,
                                        @NotNull Set<? extends K> dataKeys,
                                        @NotNull Processor<? super VirtualFile> processor,
                                        @NotNull GlobalSearchScope filter) {
    return true;
  }

  @Override
  public void ignoreDumbMode(@NotNull Runnable command, @NotNull DumbModeAccessType dumbModeAccessType) {
    ignoreDumbMode(dumbModeAccessType, () -> {
      command.run();
      return null;
    });
  }

  @Override
  public <T, E extends Throwable> T ignoreDumbMode(@NotNull DumbModeAccessType dumbModeAccessType,
                                                   @NotNull ThrowableComputable<T, E> computable) throws E {
    boolean setAccessType = true;
    DumbModeAccessType currentAccessType = ourDumbModeAccessType.get();
    if (currentAccessType != null) {
      if (currentAccessType == dumbModeAccessType) {
        setAccessType = false;
      }
      else {
        throw new AssertionError(
          "Reentrant dumb mode ignorance. Current mode: " + currentAccessType + ", Requested mode: " + dumbModeAccessType);
      }
    }
    if (setAccessType) ourDumbModeAccessType.set(dumbModeAccessType);
    try {
      return computable.compute();
    }
    finally {
      if (setAccessType) ourDumbModeAccessType.set(null);
    }
  }

  @Override
  public <K> boolean processAllKeys(@NotNull ID<K, ?> indexId, @NotNull Processor<? super K> processor, @Nullable Project project) {
    return true;
  }

  @Override
  public <K> boolean processAllKeys(@NotNull ID<K, ?> indexId,
                                    @NotNull Processor<? super K> processor,
                                    @NotNull GlobalSearchScope scope,
                                    @Nullable IdFilter idFilter) {
    return super.processAllKeys(indexId, processor, scope, idFilter);
  }

  @Override
  public @NotNull <K, V> Map<K, V> getFileData(@NotNull ID<K, V> id, @NotNull VirtualFile virtualFile, @NotNull Project project) {
    return Collections.emptyMap();
  }

  @Override
  public void invalidateCaches() {
  }

  @Override
  public @NotNull IntPredicate getAccessibleFileIdFilter(@Nullable Project project) {
    return value -> false;
  }

  @Override
  public ProjectIndexableFilesFilter projectIndexableFiles(@Nullable Project project) {
    return null;
  }

  @Override
  public void waitUntilIndicesAreInitialized() {
  }

  @Override
  public <K> boolean ensureUpToDate(@NotNull ID<K, ?> indexId,
                                    @Nullable Project project,
                                    @Nullable GlobalSearchScope filter,
                                    @Nullable VirtualFile restrictedFile) {
    return true;
  }

  @Override
  public @NotNull List<IndexableFilesProvider> getOrderedIndexableFilesProviders(@NotNull Project project) {
    return super.getOrderedIndexableFilesProviders(project);
  }

  @Override
  public <K, V> UpdatableIndex<K, V, FileContent> getIndex(ID<K, V> indexId) {
    return EmptyIndex.getInstance();
  }

  private static class EmptyIndex<Key, Value> implements UpdatableIndex<Key, Value, FileContent> {
    @SuppressWarnings("rawtypes")
    private static final EmptyIndex INSTANCE = new EmptyIndex();
    private final ReentrantReadWriteLock myLock = new ReentrantReadWriteLock();


    @SuppressWarnings("unchecked")
    static <Key, Value> EmptyIndex<Key, Value> getInstance() {
      return INSTANCE;
    }

    @Override
    public boolean processAllKeys(@NotNull Processor<? super Key> processor,
                                  @NotNull GlobalSearchScope scope,
                                  @Nullable IdFilter idFilter) {
      return true;
    }

    @Override
    public @NotNull ReadWriteLock getLock() {
      return myLock;
    }

    @Override
    public @NotNull Map<Key, Value> getIndexedFileData(int fileId) {
      return Collections.emptyMap();
    }

    @Override
    public void setIndexedStateForFile(int fileId, @NotNull IndexedFile file) {
      throw new UnsupportedOperationException();
    }

    @Override
    public void resetIndexedStateForFile(int fileId) {
      throw new UnsupportedOperationException();
    }

    @Override
    public @NotNull FileIndexingState getIndexingStateForFile(int fileId, @NotNull IndexedFile file) {
      throw new UnsupportedOperationException();
    }

    @Override
    public long getModificationStamp() {
      return 0;
    }

    @Override
    public void removeTransientDataForFile(int inputId) {
    }

    @Override
    public void removeTransientDataForKeys(int inputId, @NotNull Collection<? extends Key> keys) {
    }

    @Override
    public @NotNull IndexExtension<Key, Value, FileContent> getExtension() {
      throw new UnsupportedOperationException();
    }

    @Override
    public void updateWithMap(@NotNull AbstractUpdateData<Key, Value> updateData) {
      throw new UnsupportedOperationException();
    }

    @Override
    public void setBufferingEnabled(boolean enabled) {
    }

    @Override
    public void cleanupMemoryStorage() {
    }

    @Override
    public void cleanupForNextTest() {
    }

    @Override
    public void dumpStatistics() {

    }

    @Override
    public @NotNull ValueContainer<Value> getData(@NotNull Key key) {
      return SnapshotSingleValueIndexStorage.empty();
    }

    @Override
    public @NotNull Computable<Boolean> mapInputAndPrepareUpdate(int inputId, @Nullable FileContent content) {
      throw new UnsupportedOperationException();
    }

    @Override
    public void flush() {
    }

    @Override
    public void clear() {
    }

    @Override
    public void dispose() {
    }

    private static final Lock NO_LOCK = new Lock() {
      @Override
      public void lock() {
      }

      @Override
      public void lockInterruptibly() {
      }

      @Override
      public boolean tryLock() {
        return false;
      }

      @Override
      public boolean tryLock(long time, @NotNull TimeUnit unit) {
        return false;
      }

      @Override
      public void unlock() {
      }

      @NotNull
      @Override
      public java.util.concurrent.locks.Condition newCondition() {
        throw new UnsupportedOperationException();
      }
    };
  }
}

==> test-framework-203.7717.56-sources.jar: com/intellij/testFramework/EmptyFileBasedIndex.java <==
// Copyright 2000-2020 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.testFramework;

import com.intellij.openapi.progress.ProgressIndicator;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.roots.ContentIterator;
import com.intellij.openapi.util.Computable;
import com.intellij.openapi.util.Condition;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.psi.search.GlobalSearchScope;
import com.intellij.util.Processor;
import com.intellij.util.indexing.*;
import com.intellij.util.indexing.impl.AbstractUpdateData;
import com.intellij.util.indexing.impl.InputDataDiffBuilder;
import com.intellij.util.indexing.snapshot.SnapshotSingleValueIndexStorage;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.*;
import java.util.concurrent.locks.ReadWriteLock;
import java.util.concurrent.locks.ReentrantReadWriteLock;
import java.util.function.IntPredicate;

public class EmptyFileBasedIndex extends FileBasedIndexEx {

  @Override
  public void iterateIndexableFiles(@NotNull ContentIterator processor, @NotNull Project project, @Nullable ProgressIndicator indicator) {
  }

  @Override
  public @Nullable VirtualFile getFileBeingCurrentlyIndexed() {
    return null;
  }

  @Override
  public void registerIndexableSet(@NotNull IndexableFileSet set, @NotNull Project project) {

  }

  @Override
  public void removeIndexableSet(@NotNull IndexableFileSet set) {

  }

  @Override
  public VirtualFile findFileById(Project project, int id) {
    return null;
  }

  @Override
  public void requestRebuild(@NotNull ID<?, ?> indexId) {
    super.requestRebuild(indexId);
  }

  @Override
  public @NotNull <K, V> List<V> getValues(@NotNull ID<K, V> indexId, @NotNull K dataKey, @NotNull GlobalSearchScope filter) {
    return Collections.emptyList();
  }

  @Override
  public @NotNull <K, V> Collection<VirtualFile> getContainingFiles(@NotNull ID<K, V> indexId,
                                                                    @NotNull K dataKey,
                                                                    @NotNull GlobalSearchScope filter) {
    return Collections.emptyList();
  }

  @Override
  public <K, V> boolean processValues(@NotNull ID<K, V> indexId,
                                      @NotNull K dataKey,
                                      @Nullable VirtualFile inFile,
                                      @NotNull ValueProcessor<? super V> processor,
                                      @NotNull GlobalSearchScope filter) {
    return true;
  }

  @Override
  public <K, V> boolean processValues(@NotNull ID<K, V> indexId,
                                      @NotNull K dataKey,
                                      @Nullable VirtualFile inFile,
                                      @NotNull ValueProcessor<? super V> processor,
                                      @NotNull GlobalSearchScope filter,
                                      @Nullable IdFilter idFilter) {
    return super.processValues(indexId, dataKey, inFile, processor, filter, idFilter);
  }

  @Override
  public <K, V> long getIndexModificationStamp(@NotNull ID<K, V> indexId, @NotNull Project project) {
    return 0;
  }

  @Override
  public <K, V> boolean processFilesContainingAllKeys(@NotNull ID<K, V> indexId,
                                                      @NotNull Collection<? extends K> dataKeys,
                                                      @NotNull GlobalSearchScope filter,
                                                      @Nullable Condition<? super V> valueChecker,
                                                      @NotNull Processor<? super VirtualFile> processor) {
    return true;
  }

  @Override
  public @NotNull <K> Collection<K> getAllKeys(@NotNull ID<K, ?> indexId, @NotNull Project project) {
    return Collections.emptyList();
  }

  @Override
  public <K> void ensureUpToDate(@NotNull ID<K, ?> indexId, @Nullable Project project, @Nullable GlobalSearchScope filter) {

  }

  @Override
  public void requestRebuild(@NotNull ID<?, ?> indexId, @NotNull Throwable throwable) {

  }

  @Override
  public <K> void scheduleRebuild(@NotNull ID<K, ?> indexId, @NotNull Throwable e) {

  }

  @Override
  public void requestReindex(@NotNull VirtualFile file) {

  }

  @Override
  public <K, V> boolean getFilesWithKey(@NotNull ID<K, V> indexId,
                                        @NotNull Set<? extends K> dataKeys,
                                        @NotNull Processor<? super VirtualFile> processor,
                                        @NotNull GlobalSearchScope filter) {
    return true;
  }

  @Override
  public <K> boolean processAllKeys(@NotNull ID<K, ?> indexId, @NotNull Processor<? super K> processor, @Nullable Project project) {
    return true;
  }

  @Override
  public <K> boolean processAllKeys(@NotNull ID<K, ?> indexId,
                                    @NotNull Processor<? super K> processor,
                                    @NotNull GlobalSearchScope scope,
                                    @Nullable IdFilter idFilter) {
    return super.processAllKeys(indexId, processor, scope, idFilter);
  }

  @Override
  public @NotNull <K, V> Map<K, V> getFileData(@NotNull ID<K, V> id, @NotNull VirtualFile virtualFile, @NotNull Project project) {
    return Collections.emptyMap();
  }

  @Override
  public void invalidateCaches() {
  }

  @Override
  public @NotNull IntPredicate getAccessibleFileIdFilter(@Nullable Project project) {
    return value -> false;
  }

  @Override
  public ProjectIndexableFilesFilter projectIndexableFiles(@Nullable Project project) {
    return null;
  }

  @Override
  public void waitUntilIndicesAreInitialized() {
  }

  @Override
  public <K> boolean ensureUpToDate(@NotNull ID<K, ?> indexId,
                                    @Nullable Project project,
                                    @Nullable GlobalSearchScope filter,
                                    @Nullable VirtualFile restrictedFile) {
    return true;
  }

  @Override
  public <K, V> UpdatableIndex<K, V, FileContent> getIndex(ID<K, V> indexId) {
    return EmptyIndex.getInstance();
  }

  private static class EmptyIndex<Key, Value> implements UpdatableIndex<Key, Value, FileContent> {
    @SuppressWarnings("rawtypes")
    private static final EmptyIndex INSTANCE = new EmptyIndex();
    private final ReentrantReadWriteLock myLock = new ReentrantReadWriteLock();


    @SuppressWarnings("unchecked")
    static <Key, Value> EmptyIndex<Key, Value> getInstance() {
      return INSTANCE;
    }

    @Override
    public boolean processAllKeys(@NotNull Processor<? super Key> processor,
                                  @NotNull GlobalSearchScope scope,
                                  @Nullable IdFilter idFilter) {
      return true;
    }

    @Override
    public @NotNull ReadWriteLock getLock() {
      return myLock;
    }

    @Override
    public @NotNull Map<Key, Value> getIndexedFileData(int fileId) {
      return Collections.emptyMap();
    }

    @Override
    public void setIndexedStateForFile(int fileId, @NotNull IndexedFile file) {
      throw new UnsupportedOperationException();
    }

    @Override
    public void invalidateIndexedStateForFile(int fileId) {
      throw new UnsupportedOperationException();
    }

    @Override
    public void setUnindexedStateForFile(int fileId) {
      throw new UnsupportedOperationException();
    }

    @Override
    public @NotNull FileIndexingState getIndexingStateForFile(int fileId, @NotNull IndexedFile file) {
      throw new UnsupportedOperationException();
    }

    @Override
    public long getModificationStamp() {
      return 0;
    }

    @Override
    public void removeTransientDataForFile(int inputId) {
    }

    @Override
    public void removeTransientDataForKeys(int inputId, @NotNull InputDataDiffBuilder<Key, Value> diffBuilder) {

    }

    @Override
    public @NotNull IndexExtension<Key, Value, FileContent> getExtension() {
      throw new UnsupportedOperationException();
    }

    @Override
    public void updateWithMap(@NotNull AbstractUpdateData<Key, Value> updateData) {
      throw new UnsupportedOperationException();
    }

    @Override
    public void setBufferingEnabled(boolean enabled) {
    }

    @Override
    public void cleanupMemoryStorage() {
    }

    @Override
    public void cleanupForNextTest() {
    }

    @Override
    public void dumpStatistics() {

    }

    @Override
    public @NotNull ValueContainer<Value> getData(@NotNull Key key) {
      return SnapshotSingleValueIndexStorage.empty();
    }

    @Override
    public @NotNull Computable<Boolean> mapInputAndPrepareUpdate(int inputId, @Nullable FileContent content) {
      throw new UnsupportedOperationException();
    }

    @Override
    public void flush() {
    }

    @Override
    public void clear() {
    }

    @Override
    public void dispose() {
    }
  }
}
